Crate mantra_lancer

Crate mantra_lancer 

A currency tracker for the LANCER TTRPG system, combination of Manna and Tracker. Provides summarizing, filtering, and multi-pilot support

Modules

app
This module provides the front end application through the App type
config
This module provides configuration data and serialization
storage
This module interfaces with the local sqlite database

Structs

CursoredString
A String with a cursor character based position for editing The cursor is always considered ‘in front’ of the character with the same index

Functions

base_dirs
Grabs the XDG dirs
value_from_modifiers
Returns an appropriatly scaled value given the held modifier keys