A currency tracker for the LANCER TTRPG system, combination of Manna and Tracker. Provides summarizing, filtering, and multi-pilot support
Modules
- app
- This module provides the front end application through the
Apptype - config
- This module provides configuration data and serialization
- storage
- This module interfaces with the local sqlite database
Structs
- Cursored
String - A String with a cursor character based position for editing The cursor is always considered ‘in front’ of the character with the same index
Functions
- base_
dirs - Grabs the XDG dirs
- value_
from_ modifiers - Returns an appropriatly scaled value given the held modifier keys